==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/Rekognition/FaceSearchSettings.pm <==
package Paws::Rekognition::FaceSearchSettings;
  use Moose;
  has CollectionId => (is => 'ro', isa => 'Str');
  has FaceMatchThreshold => (is => 'ro', isa => 'Num');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Rekognition::FaceSearchSettings

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Rekognition::FaceSearchSettings object:

  $service_obj->Method(Att1 => { CollectionId => $value, ..., FaceMatchThreshold => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Rekognition::FaceSearchSettings object:

  $result = $service_obj->Method(...);
  $result->Att1->CollectionId

=head1 DESCRIPTION

Input face recognition parameters for an Amazon Rekognition stream
processor. C<FaceRecognitionSettings> is a request parameter for .

=head1 ATTRIBUTES


=head2 CollectionId => Str

  The ID of a collection that contains faces that you want to search for.


=head2 FaceMatchThreshold => Num

  Minimum face match confidence score that must be met to return a result
for a recognized face. Default is 70. 0 is the lowest confidence. 100
is the highest confidence.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Rekognition>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/Rekognition/FaceSearchSettings.pm <==
package Paws::Rekognition::FaceSearchSettings;
  use Moose;
  has CollectionId => (is => 'ro', isa => 'Str');
  has FaceMatchThreshold => (is => 'ro', isa => 'Num');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Rekognition::FaceSearchSettings

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Rekognition::FaceSearchSettings object:

  $service_obj->Method(Att1 => { CollectionId => $value, ..., FaceMatchThreshold => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Rekognition::FaceSearchSettings object:

  $result = $service_obj->Method(...);
  $result->Att1->CollectionId

=head1 DESCRIPTION

Input face recognition parameters for an Amazon Rekognition stream
processor. C<FaceRecognitionSettings> is a request parameter for
CreateStreamProcessor.

=head1 ATTRIBUTES


=head2 CollectionId => Str

  The ID of a collection that contains faces that you want to search for.


=head2 FaceMatchThreshold => Num

  Minimum face match confidence score that must be met to return a result
for a recognized face. Default is 70. 0 is the lowest confidence. 100
is the highest confidence.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Rekognition>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
